@@ -261,15 +261,18 @@ class Byneuron:
             if r:
                 return r.get('publicId')
 
-    def _list_indexsetkeys(self, indexsets):
+    def _data_indexsets(self, indexsets):
         """
         used for event and entity queries
-        :param indexsets:
+        :param indexsets: (list of) entities or indexsetKeys,
+        special cases: None, use active indexset; True: use all indexsets
         :return:
         """
         indexsetlist = indexsets if isinstance(indexsets, list) else [indexsets]
         indexsets = set()
         for i in indexsetlist:
+            if i is True:
+                indexsets.update({i.indexset for i in self.indexsets})  # all indexsets
             if isinstance(i, Entity):
                 indexsets.update({i.indexset})
             elif isinstance(i, str):
@@ -277,8 +280,11 @@ class Byneuron:
             elif i is None:
                 indexsets.update({self.indexset_active.key})
         return list(indexsets)
-
-    def _numberevents(self, size=100, order="DESC", deleted=False, indexsets=None, filters=None):
+    
+    def _data_sort(self, order):
+        return 'DESC' if order == 'DESC' else 'ASC'
+    
+    def _numberevents(self, size=100, order=None, deleted=False, indexsets=None, filters=None):
         """
         :param size:
         :param order:
@@ -289,8 +295,8 @@ class Byneuron:
         """
         filters = [] if not isinstance(filters, list) else filters
         data = {
-            "indexSets": self._list_indexsetkeys(indexsets),  # list of indexSet keys
-            "order": order,  # "ASC","DESC"  # order is respected after 'size' number of most recent events
+            "indexSets": self._data_indexsets(indexsets),  # list of indexSet keys
+            "order": self._data_sort(order),  # "ASC","DESC"  # order is respected after 'size' number of most recent events
             # have been collected; so "DESC" gives the most consistent result
             "size": int(size),
             "deleted": bool(deleted),
@@ -298,6 +304,7 @@ class Byneuron:
             "esDocumentType": "NumberEvent"
         }
         url = f'{self.api}/backend/rest/numberevents/_query'
+        log.debug('data for _numberevents %s', data)
         return self.url(url=url, data=data)
 
     def _datehistogramtimeline(self, items, aggrs, from_date, to_date, interval,
@@ -352,9 +359,9 @@ class Byneuron:
         }
         data = {
             "query": {
-                "indexSets": self._list_indexsetkeys(items),
+                "indexSets": self._data_indexsets(items),
                 "sortField": "timestamp",
-                "order": "ASC" if order is None else order,
+                "order": self._data_sort(order),
                 "deleted": False if deleted is None else bool(False),
                 "filters": filters,
                 "esDocumentType": "NumberEvent"
@@ -390,7 +397,7 @@ class Byneuron:
     def get_numberevents_dict(self, item, size):
         return {e.datetime: e.value for e in self.get_numberevents(item=item, size=size)}
 
-    def get_numberevents_dates(self, item, from_date=None, to_date=None, extend=None):
+    def get_numberevents_dates(self, item, from_date=None, to_date=None, extend=None, order=None):
         """
         retrieve events for item as Numberevent() between two points in time
         :param item: entity of type item
@@ -404,9 +411,10 @@ class Byneuron:
             from_date = self.now
         if not isinstance(to_date, datetime.datetime):
             to_date = self.now
-        order = 'DESC'
+        order = self._data_sort(order)
         items = item if isinstance(item, list) else [item]
         item_keys = list({i.key if isinstance(i, Entity) else i for i in items})
+        indexset_keys = self._data_indexsets(items)
         f_item = {
             "type": "eventitemid",
             "values": item_keys,
@@ -415,16 +423,16 @@ class Byneuron:
         }
         f_range = {
             "type": "range",
-            "to": max(from_date, to_date).timestamp() * 1000,
+            "to": int(max(from_date, to_date).timestamp() * 1000),
             "maxInclusive": False
         }
         if not extend:
             f_range.update({
-                "from": min(from_date, to_date).timestamp() * 1000,
+                "from": int(min(from_date, to_date).timestamp() * 1000),
                 "minInclusive": True
             })
         while True:
-            data = self._numberevents(indexsets=items, order=order, filters=[f_item, f_range])
+            data = self._numberevents(indexsets=indexset_keys, order=order, filters=[f_item, f_range])
             if data:
                 for i in data:
                     event = Numberevent(datamodel=i)
@@ -591,16 +599,10 @@ class Byneuron:
                 return f'value:any'
             elif v is None:
                 return f'value:none'
-        if indexset is True:
-            entity_list = self.indexsets  # all indexSets
-        elif isinstance(indexset, list):
-            entity_list = [i for i in indexset if isinstance(i, Entity)]  # specify multiple indexSets
-        elif isinstance(indexset, str):
-            entity_list = [i for i in self.indexsets if i.name == indexset or i.key == indexset]
-        else:
-            entity_list = [self.indexset_active]  # default to active indexSet
+
+        entity_list = self._data_indexsets(indexset)
         query = [
-            f"IndexSet:?indexSet entity:key {[i.key for i in entity_list]}.",
+            f"IndexSet:?indexSet entity:key {entity_list}.",
             f"{entitytype}:?e link:{'isAssignedTo' if entitytype == 'Gateway' else 'isDefinedIn'} ?indexSet."
         ]
         filter_list = []
